@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"os"
+	"rare/cmd/helpers"
 	"rare/pkg/testutil"
 	"testing"
 
@@ -16,6 +17,20 @@ func TestFilter(t *testing.T) {
 	)
 }
 
+func TestSarch(t *testing.T) {
+	testCommandSet(t, searchCommand(),
+		`the testdata/log.txt`,
+		`testtest`,
+	)
+}
+
+func TestSearchOutput(t *testing.T) {
+	out, eout, err := testCommandCapture(searchCommand(), `last testdata/*.txt`)
+	assert.NoError(t, err)
+	assert.Equal(t, "testdata/log.txt 3: 5 is the last\n", out)
+	assert.Equal(t, "Read   : 5 file(s) (9.41 KB)\nMatched: 1 / 76\n", eout)
+}
+
 func TestFilterExtract(t *testing.T) {
 	out, eout, err := testCommandCapture(filterCommand(), `-m (\d+) -e "{1}" testdata/log.txt`)
 	assert.NoError(t, err)
@@ -23,6 +38,13 @@ func TestFilterExtract(t *testing.T) {
 	assert.Equal(t, "Matched: 3 / 6\n", eout)
 }
 
+func TestFilterLine(t *testing.T) {
+	out, eout, err := testCommandCapture(filterCommand(), `-l -m (\d+) -e "{1}" testdata/log.txt`)
+	assert.NoError(t, err)
+	assert.Equal(t, "testdata/log.txt 1: 5\ntestdata/log.txt 2: 22\ntestdata/log.txt 3: 5\n", out)
+	assert.Equal(t, "Matched: 3 / 6\n", eout)
+}
+
 func TestFilterMultiExtract(t *testing.T) {
 	out, eout, err := testCommandCapture(filterCommand(), `-m (\d+) -e "{1}" -e "b-{1}" testdata/log.txt`)
 	assert.NoError(t, err)
@@ -70,7 +92,7 @@ func TestFilterFromStdin(t *testing.T) {
 func TestFilterFileNotExist(t *testing.T) {
 	out, eout, err := testCommandCapture(filterCommand(), `-m (\d+) -e "{1}" testdata/no-exist.txt`)
 	assert.Error(t, err)
-	assert.Equal(t, 2, err.(cli.ExitCoder).ExitCode())
+	assert.Equal(t, helpers.ExitCodeReadError, err.(cli.ExitCoder).ExitCode())
 	assert.Equal(t, "", out)
 	assert.Equal(t, "Matched: 0 / 0\nRead errors", eout)
 }
