@@ -80,11 +80,26 @@ func TestPercentFunction(t *testing.T) {
 	testExpression(t, mockContext("0.12345"), "{percent {0}}", "12.3%")
 	testExpression(t, mockContext("0.12345"), "{percent {0} 2}", "12.35%")
 	testExpressionErr(t, mockContext("0.12345"), "{percent {0} {0}}", "<CONST>", ErrConst)
+
+	testExpression(t, mockContext("0.12345"), "{percent {0} 2 0.5}", "24.69%")
+	testExpression(t, mockContext("50"), "{percent {0} 0 25 75}", "50%")
+
+	testExpressionErr(t, mockContext(), "{percent 0 1 2 3 4 5}", "<ARGN>", ErrArgCount)
+	testExpressionErr(t, mockContext(), "{percent 0 1 a}", "<BAD-TYPE>", ErrNum)
 }
 
-func TestByteSize(t *testing.T) {
+func TestDownscalers(t *testing.T) {
 	testExpression(t, mockContext("1000000"), "{bytesize {0}}", "977 KB")
 	testExpression(t, mockContext("1000000"), "{bytesize {0} 2}", "976.56 KB")
+	testExpressionErr(t, mockContext("1000000"), "{bytesize {0} 2 3}", "<ARGN>", ErrArgCount)
+
+	testExpression(t, mockContext("1000000"), "{bytesizesi {0}}", "1 mB")
+	testExpression(t, mockContext("1000000"), "{bytesizesi {0} 2}", "1.00 mB")
+	testExpressionErr(t, mockContext("1000000"), "{bytesizesi {0} 2 3}", "<ARGN>", ErrArgCount)
+
+	testExpression(t, mockContext("5120000"), "{downscale {0}}", "5M")
+	testExpression(t, mockContext("5120000"), "{downscale {0} 2}", "5.12M")
+	testExpressionErr(t, mockContext("5120000"), "{downscale {0} 2 3}", "<ARGN>", ErrArgCount)
 }
 
 func TestFormat(t *testing.T) {
@@ -116,3 +131,8 @@ func BenchmarkSelectItem(b *testing.B) {
 		selectField("this  is\ta\ntest\x00really", 1)
 	}
 }
+
+// BenchmarkPercent/{percent_50_1_0_100}-4         	 3397647	       341.3 ns/op	       5 B/op	       1 allocs/op
+func BenchmarkPercent(b *testing.B) {
+	benchmarkExpression(b, mockContext(), "{percent 50 1 0 100}", "50.0%")
+}
